/*
** Module   : SOAPHeaderEntryImpl.java
** Abstract : Implementation for the SOAP-HEADER-ENTRY resource.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130216 Created initial version.
** 002 CA  20130221 Added ADM-DATA, LOCAL-NAME, UNIQUE-ID and NAMESPACE-URI support. Fixed 
**                  resource type.
** 003 OM  20130304 Refactored isValid and isUnknown of WrappedResource to valid and unknown.
** 004 CA  20130603 resourceDelete must return a boolean value.
*/

package com.goldencode.p2j.util;

/**
 * A class for implementing the SOAP-HEADER-ENTRYREF method and attributes.
 * TODO: add support only for NAME and PRIVATE-DATA attributes (without PREV-/NEXT-SIBLING)
 */
public class SOAPHeaderEntryImpl
extends HandleChain
implements SOAPHeaderEntry,
           SOAPEntity
{
   /**
    * Default c'tor. Sets the resource type.
    */
   public SOAPHeaderEntryImpl()
   {
      setResourceType("SOAP-HEADER-ENTRYREF");
   }

   /**
    * Gets the X-NODEREF object that refers to the XML underlying a SOAP-HEADER-ENTRYREF object or
    * SOAP-FAULT entry and sets it to the given handle..
    * <p>
    * This method returns a logical even though the Progress 4GL documentation explicitly states 
    * otherwise. Actual working code has proven that the original documentation is incorrect. 
    * This implementation matches the actual runtime behavior of the 4GL.
    * 
    * @param    xNode
    *           The handle where the resource will be set.
    *           
    * @return   <code>true</code> if the operation was possible.
    */
   public logical getNode(handle xNode)
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Returns a LONGCHAR that contains the serialized form of the XML underlying the 
    * SOAP-HEADER-ENTRYREF or SOAP-FAULT entry.
    * 
    * @return   See above.
    */
   public longchar getSerialized()
   {
      // TODO: implement this
      return new longchar();
   }

   /**
    * Returns the value of the actor attribute for the SOAP-HEADER-ENTRYREF object as a URL. 
    * Identifies the recipient of a header element.
    * 
    * @return   See above.
    */
   public character getActor()
   {
      // TODO: implement this
      return new character();
   }

   /**
    * Indicates whether a SOAP-HEADER-ENTRYREF object is mandatory (TRUE) or optional (FALSE) for
    * the recipient to process.
    * 
    * @return   See above.
    */
   public logical isMustUnderstand()
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Deletes the XML underlying a SOAP-HEADER-ENTRYREF object, without deleting the object.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical deleteHeaderEntry()
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Sets the ACTOR attribute for this SOAP-HEADER-ENTRY.
    *
    * @param    uri
    *           The URI of the SOAP actor.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setActor(character uri)
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Sets the ACTOR attribute for this SOAP-HEADER-ENTRY.
    *
    * @param    uri
    *           The URI of the SOAP actor.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setActor(String uri)
   {
      return setActor(new character(uri));
   }

   /**
    * Sets the MUST-UNDERSTAND attribute for this SOAP-HEADER-ENTRY.
    *
    * @param    val
    *           The new value of this attribute.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setMustUnderstand(logical val)
   {
      return setMustUnderstand(new logical(val));
   }

   /**
    * Sets the MUST-UNDERSTAND attribute for this SOAP-HEADER-ENTRY.
    *
    * @param    val
    *           The new value of this attribute.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setMustUnderstand(boolean val)
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Replaces the underlying XML of a SOAP-HEADER-ENTRYREF object with the DOM XML sub-tree 
    * rooted by the X-NODEREF object.
    *
    * @param    xNoderef
    *           A X-NODEREF variable that refers to the XML that will be set for the 
    *           SOAP-HEADER-ENTRYREF object.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setNode(handle xNoderef)
   {
      // TODO: implement this
      return new logical();
   }

   /**
    * Sets the SOAP-header-entryref object's underlying XML from serialized XML.
    *
    * @param    xml
    *           A LONGCHAR variable that contains the XML that will become this 
    *           SOAP-HEADER-ENTRYREF object. This parameter can be only a longchar, 4GL doesn't
    *           allow character variables.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical setSerialized(longchar xml)
   {
      // TODO: implement this
      return new logical();
   }
   
   /**
    * Reports if this object is valid for use.  
    *
    * @return   <code>true</code> if we are valid (can be used).
    */
   public boolean valid()
   {
      // TODO: implement this
      return false;
   }

   /**
    * Get the value of the LOCAL-NAME attribute.
    * 
    * @return   See above.
    */
   @Override
   public character getLocalName()
   {
      // TODO Auto-generated method stub
      return null;
   }

   /**
    * Set the value of the LOCAL-NAME attribute. This method is readonly.
    */
   @Override
   public void setLocalName(character localName)
   {
      //TODO autogenerated code by evk, please fix this
   }

   /**
    * Get the value of the ADM-DATA attribute.
    * 
    * @return   See above.
    */
   @Override
   public character getADMData()
   {
      // TODO Auto-generated method stub
      return null;
   }

   /**
    * Set the value of the ADM-DATA attribute.
    * 
    * @param    value
    *           The new value.
    */
   @Override
   public void setADMData(String value)
   {
      // TODO Auto-generated method stub
   }

   /**
    * Set the value of the ADM-DATA attribute.
    * 
    * @param    value
    *           The new value.
    */
   @Override
   public void setADMData(character value)
   {
      // TODO Auto-generated method stub
   }

   /**
    * Gets the the unique ID number associated to this object by the underlying system. Not the 
    * same as the handle value itself.
    * 
    * @return   The integer number of the children.
    */
   @Override
   public integer getUniqueID()
   {
      // TODO Auto-generated method stub
      return null;
   }

   /**
    * Returns the value of the the NAMESPACE-URI attribute.
    *
    * @return    See above.
    */
   @Override
   public character getNamespaceURI()
   {
      // TODO Auto-generated method stub
      return null;
   }

   /**
    * Setter for NAMESPACE-URI attribute. Calls {@link #readOnlyError}, as this attribute is r/o
    * for this resource.
    *
    * @param    uri
    *           Not used.
    */
   @Override
   public void setNamespaceURI(String uri)
   {
      readOnlyError("NAMESPACE-URI");
   }

   /**
    * Setter for NAMESPACE-URI attribute. Calls {@link #readOnlyError}, as this attribute is r/o
    * for this resource.
    *
    * @param    uri
    *           Not used.
    */
   @Override
   public void setNamespaceURI(character uri)
   {
      readOnlyError("NAMESPACE-URI");
   }

   /**
    * Delete the resource.
    * 
    * @return   <code>true</code> if the resource was deleted.
    */
   @Override
   protected boolean resourceDelete()
   {
      // TODO Auto-generated method stub
      return false;
   }
}
